@@ -25,14 +25,14 @@ DEFAULT_BASE_TAGS = {
     'centos': '7',
     'rhel': '7',
     'oraclelinux': '7-slim',
-    'debian': 'stretch',
+    'debian': 'stretch-backports',
     'ubuntu': '16.04',
 }
 DISTRO_RELEASE = {
     'centos': '7',
     'rhel': '7',
     'oraclelinux': '7',
-    'debian': 'stretch',
+    'debian': 'stretch-backports',
     'ubuntu': '16.04',
 }
 
@@ -46,7 +46,7 @@ DELOREAN = \
 DELOREAN_DEPS = {
     'x86_64': "https://trunk.rdoproject.org/centos7/delorean-deps.repo",
     'aarch64': "",
-    'ppc64le': ""
+    'ppc64le': "https://trunk.rdoproject.org/centos7/delorean-deps.repo"
 }
 
 INSTALL_TYPE_CHOICES = ['binary', 'source', 'rdo', 'rhos']
@@ -57,6 +57,7 @@ _PROFILE_OPTS = [
     cfg.ListOpt('infra',
                 default=[
                     'ceph',
+                    'certmonger',
                     'cron',
                     'elasticsearch',
                     'etcd',
@@ -70,9 +71,11 @@ _PROFILE_OPTS = [
                     'mongodb',
                     'opendaylight',
                     'openvswitch',
+                    'ptp',
                     'qdrouterd',
                     'rabbitmq',
                     'redis',
+                    'rsyslog',
                     'skydive',
                     'tgtd',
                 ],
@@ -93,6 +96,7 @@ _PROFILE_OPTS = [
                 help='Main images'),
     cfg.ListOpt('aux',
                 default=[
+                    'almanach',
                     'aodh',
                     'blazar',
                     'cloudkitty',
@@ -176,14 +180,11 @@ hostarch = os.uname()[4]
 _CLI_OPTS = [
     cfg.StrOpt('base', short='b', default='centos',
                choices=BASE_OS_DISTRO,
-               help='The distro type of the base image. Allowed values '
-                    'are ' + ', '.join(BASE_OS_DISTRO)),
+               help='The distro type of the base image.'),
     cfg.StrOpt('base-tag', default='latest',
                help='The base distro image tag'),
     cfg.StrOpt('base-image',
-               help='The base image name. Default is the same with base. '
-                    'For non-x86 architectures use full name like '
-                    '"aarch64/debian".'),
+               help='The base image name. Default is the same with base.'),
     cfg.StrOpt('base-arch', default=hostarch,
                choices=BASE_ARCH,
                help='The base architecture. Default is same as host'),
@@ -236,8 +237,7 @@ _CLI_OPTS = [
     cfg.StrOpt('type', short='t', default='binary',
                choices=INSTALL_TYPE_CHOICES,
                dest='install_type',
-               help=('The method of the OpenStack install. Allowed values '
-                     'are ' + ', '.join(INSTALL_TYPE_CHOICES))),
+               help=('The method of the OpenStack install.')),
     cfg.IntOpt('threads', short='T', default=8, min=1,
                help=('The number of threads to use while building.'
                      ' (Note: setting to one will allow real time'
@@ -257,18 +257,26 @@ _CLI_OPTS = [
     cfg.BoolOpt('pull', default=True,
                 help='Attempt to pull a newer version of the base image'),
     cfg.StrOpt('work-dir', help=('Path to be used as working directory.'
-                                 'By default, a temporary dir is created')),
+                                 ' By default, a temporary dir is created')),
+    cfg.BoolOpt('squash', default=False,
+                help=('Squash the image layers. WARNING: it will consume lots'
+                      ' of disk IO. "docker-squash" tool is required, install'
+                      ' it by "pip install docker-squash"')),
 ]
 
 _BASE_OPTS = [
     cfg.StrOpt('maintainer',
                default='Kolla Project (https://launchpad.net/kolla)',
-               help='The MAINTAINER field'),
+               help='Content of the maintainer label'),
     cfg.ListOpt('rpm_setup_config', default=[],
                 help=('Comma separated list of .rpm or .repo file(s) '
                       'or URL(s) to install before building containers')),
     cfg.StrOpt('apt_sources_list', help=('Path to custom sources.list')),
-    cfg.StrOpt('apt_preferences', help=('Path to custom apt/preferences'))
+    cfg.StrOpt('apt_preferences', help=('Path to custom apt/preferences')),
+    cfg.BoolOpt('squash-cleanup', default=True,
+                help='Remove source image from Docker after squashing'),
+    cfg.StrOpt('squash-tmp-dir',
+               help='Temporary directory to be used during squashing')
 ]
 
 
@@ -276,322 +284,354 @@ SOURCES = {
     'openstack-base': {
         'type': 'url',
         'location': ('$tarballs_base/requirements/'
-                     'requirements-stable-pike.tar.gz')},
+                     'requirements-stable-queens.tar.gz')},
+    'almanach-base': {
+        'type': 'url',
+        'location': ('$tarballs_base/almanach/'
+                     'almanach-stable-queens.tar.gz')},
     'aodh-base': {
         'type': 'url',
         'location': ('$tarballs_base/aodh/'
-                     'aodh-5.1.0.tar.gz')},
+                     'aodh-6.0.1.tar.gz')},
     'barbican-base': {
         'type': 'url',
         'location': ('$tarballs_base/barbican/'
-                     'barbican-5.0.1.tar.gz')},
+                     'barbican-6.0.1.tar.gz')},
     'bifrost-base': {
         'type': 'url',
         'location': ('$tarballs_base/bifrost/'
-                     'bifrost-4.0.1.tar.gz')},
+                     'bifrost-5.0.1.tar.gz')},
     'blazar-base': {
         'type': 'url',
         'location': ('$tarballs_base/blazar/'
-                     'blazar-0.3.0.tar.gz')},
+                     'blazar-1.0.0.tar.gz')},
     'ceilometer-base': {
         'type': 'url',
         'location': ('$tarballs_base/ceilometer/'
-                     'ceilometer-9.0.6.tar.gz')},
+                     'ceilometer-10.0.1.tar.gz')},
     'ceilometer-base-plugin-panko': {
         'type': 'url',
         'location': ('$tarballs_base/panko/'
-                     'panko-3.1.0.tar.gz')},
+                     'panko-4.0.1.tar.gz')},
     'cinder-base': {
         'type': 'url',
         'location': ('$tarballs_base/cinder/'
-                     'cinder-11.2.0.tar.gz')},
+                     'cinder-12.0.3.tar.gz')},
     'congress-base': {
         'type': 'url',
         'location': ('$tarballs_base/congress/'
-                     'congress-6.0.1.tar.gz')},
+                     'congress-7.0.0.tar.gz')},
     'cloudkitty-base': {
         'type': 'url',
         'location': ('$tarballs_base/cloudkitty/'
-                     'cloudkitty-6.0.0.tar.gz')},
+                     'cloudkitty-7.0.0.tar.gz')},
     'designate-base': {
         'type': 'url',
         'location': ('$tarballs_base/designate/'
-                     'designate-5.0.2.tar.gz')},
+                     'designate-6.0.1.tar.gz')},
     'dragonflow-base': {
         'type': 'url',
         'location': ('$tarballs_base/dragonflow/'
-                     'dragonflow-4.0.0.tar.gz')},
+                     'dragonflow-master.tar.gz')},
     'ec2-api': {
         'type': 'url',
         'location': ('$tarballs_base/ec2-api/'
-                     'ec2-api-5.0.0.tar.gz')},
+                     'ec2-api-6.0.0.tar.gz')},
     'freezer-api': {
         'type': 'url',
         'location': ('$tarballs_base/freezer-api/'
-                     'freezer-api-5.0.0.tar.gz')},
+                     'freezer-api-6.0.0.tar.gz')},
     'freezer-base': {
         'type': 'url',
         'location': ('$tarballs_base/freezer/'
-                     'freezer-5.0.0.tar.gz')},
+                     'freezer-6.0.0.tar.gz')},
     'glance-base': {
         'type': 'url',
         'location': ('$tarballs_base/glance/'
-                     'glance-15.0.1.tar.gz')},
+                     'glance-16.0.1.tar.gz')},
     'gnocchi-base': {
         'type': 'git',
-        'reference': '4.1.2',
+        'reference': '4.2.0',
         'location': ('https://github.com/gnocchixyz/'
                      'gnocchi.git')},
     'heat-base': {
         'type': 'url',
         'location': ('$tarballs_base/heat/'
-                     'heat-9.0.5.tar.gz')},
+                     'heat-10.0.1.tar.gz')},
     'horizon': {
         'type': 'url',
         'location': ('$tarballs_base/horizon/'
-                     'horizon-12.0.3.tar.gz')},
+                     'horizon-13.0.1.tar.gz')},
     'horizon-plugin-cloudkitty-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/cloudkitty-dashboard/'
-                     'cloudkitty-dashboard-6.0.0.tar.gz')},
+                     'cloudkitty-dashboard-7.0.0.tar.gz')},
     'horizon-plugin-designate-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/designate-dashboard/'
-                     'designate-dashboard-5.0.1.tar.gz')},
+                     'designate-dashboard-6.0.0.tar.gz')},
     'horizon-plugin-fwaas-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-fwaas-dashboard/'
-                     'neutron-fwaas-dashboard-1.0.0.tar.gz')},
+                     'neutron-fwaas-dashboard-1.3.0.tar.gz')},
     'horizon-plugin-freezer-web-ui': {
         'type': 'url',
         'location': ('$tarballs_base/freezer-web-ui/'
-                     'freezer-web-ui-5.0.0.tar.gz')},
+                     'freezer-web-ui-6.0.0.tar.gz')},
+    'horizon-plugin-heat-dashboard': {
+        'type': 'url',
+        'location': ('$tarballs_base/heat-dashboard/'
+                     'heat-dashboard-1.0.2.tar.gz')},
     'horizon-plugin-ironic-ui': {
         'type': 'url',
         'location': ('$tarballs_base/ironic-ui/'
-                     'ironic-ui-3.0.3.tar.gz')},
+                     'ironic-ui-3.1.2.tar.gz')},
     'horizon-plugin-karbor-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/karbor-dashboard/'
-                     'karbor-dashboard-0.4.0.tar.gz')},
+                     'karbor-dashboard-1.0.0.tar.gz')},
     'horizon-plugin-magnum-ui': {
         'type': 'url',
         'location': ('$tarballs_base/magnum-ui/'
-                     'magnum-ui-3.0.0.tar.gz')},
+                     'magnum-ui-4.0.0.tar.gz')},
     'horizon-plugin-manila-ui': {
         'type': 'url',
         'location': ('$tarballs_base/manila-ui/'
-                     'manila-ui-2.10.2.tar.gz')},
+                     'manila-ui-2.13.0.tar.gz')},
     'horizon-plugin-mistral-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/mistral-dashboard/'
-                     'mistral-dashboard-5.2.4.tar.gz')},
+                     'mistral-dashboard-6.0.1.tar.gz')},
     'horizon-plugin-monasca-ui': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-ui/'
-                     'monasca-ui-1.8.0.tar.gz')},
+                     'monasca-ui-1.12.1.tar.gz')},
     'horizon-plugin-murano-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/murano-dashboard/'
-                     'murano-dashboard-4.0.0.tar.gz')},
+                     'murano-dashboard-5.0.0.tar.gz')},
     'horizon-plugin-neutron-lbaas-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-lbaas-dashboard/'
-                     'neutron-lbaas-dashboard-3.0.2.tar.gz')},
+                     'neutron-lbaas-dashboard-4.0.0.tar.gz')},
+    'horizon-plugin-octavia-dashboard': {
+        'type': 'url',
+        'location': ('$tarballs_base/octavia-dashboard/'
+                     'octavia-dashboard-1.0.1.tar.gz')},
     'horizon-plugin-sahara-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/sahara-dashboard/'
-                     'sahara-dashboard-7.0.3.tar.gz')},
+                     'sahara-dashboard-8.0.1.tar.gz')},
     'horizon-plugin-searchlight-ui': {
         'type': 'url',
         'location': ('$tarballs_base/searchlight-ui/'
-                     'searchlight-ui-3.0.0.tar.gz')},
+                     'searchlight-ui-4.0.0.tar.gz')},
     'horizon-plugin-senlin-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/senlin-dashboard/'
-                     'senlin-dashboard-0.7.0.tar.gz')},
+                     'senlin-dashboard-0.8.0.tar.gz')},
     'horizon-plugin-solum-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/solum-dashboard/'
-                     'solum-dashboard-2.2.0.tar.gz')},
+                     'solum-dashboard-2.3.0.tar.gz')},
     'horizon-plugin-tacker-dashboard': {
         'type': 'url',
-        'location': ('http://tarballs.openstack.org/tacker-horizon/'
-                     'tacker-horizon-0.10.0.tar.gz')},
+        'location': ('$tarballs_base/tacker-horizon/'
+                     'tacker-horizon-0.11.0.tar.gz')},
     'horizon-plugin-trove-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/trove-dashboard/'
-                     'trove-dashboard-9.0.0.tar.gz')},
+                     'trove-dashboard-10.0.0.tar.gz')},
+    'horizon-plugin-vitrage-dashboard': {
+        'type': 'url',
+        'location': ('$tarballs_base/vitrage-dashboard/'
+                     'vitrage-dashboard-1.4.2.tar.gz')},
     'horizon-plugin-watcher-dashboard': {
         'type': 'url',
         'location': ('$tarballs_base/watcher-dashboard/'
-                     'watcher-dashboard-1.4.0.tar.gz')},
+                     'watcher-dashboard-1.8.0.tar.gz')},
     'horizon-plugin-zaqar-ui': {
         'type': 'url',
         'location': ('$tarballs_base/zaqar-ui/'
-                     'zaqar-ui-3.0.0.tar.gz')},
+                     'zaqar-ui-4.0.1.tar.gz')},
     'horizon-plugin-zun-ui': {
         'type': 'url',
         'location': ('$tarballs_base/zun-ui/'
-                     'zun-ui-0.2.0.tar.gz')},
+                     'zun-ui-1.0.0.tar.gz')},
     'ironic-base': {
         'type': 'url',
         'location': ('$tarballs_base/ironic/'
-                     'ironic-9.1.6.tar.gz')},
+                     'ironic-10.1.3.tar.gz')},
     'ironic-inspector': {
         'type': 'url',
         'location': ('$tarballs_base/ironic-inspector/'
-                     'ironic-inspector-6.0.3.tar.gz')},
+                     'ironic-inspector-7.2.1.tar.gz')},
     'karbor-base': {
         'type': 'url',
         'location': ('$tarballs_base/karbor/'
-                     'karbor-0.5.1.tar.gz')},
+                     'karbor-1.0.0.tar.gz')},
     'keystone-base': {
         'type': 'url',
         'location': ('$tarballs_base/keystone/'
-                     'keystone-12.0.2.tar.gz')},
+                     'keystone-13.0.0.tar.gz')},
     'kuryr-base': {
         'type': 'url',
         'location': ('$tarballs_base/kuryr/'
-                     'kuryr-lib-0.6.0.tar.gz')},
+                     'kuryr-lib-0.7.0.tar.gz')},
     'kuryr-libnetwork': {
         'type': 'url',
         'location': ('$tarballs_base/kuryr-libnetwork/'
-                     'kuryr-libnetwork-0.2.0.tar.gz')},
+                     'kuryr-libnetwork-1.0.0.tar.gz')},
     'magnum-base': {
         'type': 'url',
         'location': ('$tarballs_base/magnum/'
-                     'magnum-5.0.1.tar.gz')},
+                     'magnum-6.1.1.tar.gz')},
     'manila-base': {
         'type': 'url',
         'location': ('$tarballs_base/manila/'
-                     'manila-5.0.3.tar.gz')},
+                     'manila-6.0.1.tar.gz')},
     'mistral-base': {
         'type': 'url',
         'location': ('$tarballs_base/mistral/'
-                     'mistral-5.2.7.tar.gz')},
+                     'mistral-6.0.3.tar.gz')},
     'mistral-base-plugin-tacker': {
         'type': 'url',
         'location': ('$tarballs_base/tacker/'
-                     'tacker-0.8.1.tar.gz')},
+                     'tacker-0.9.0.tar.gz')},
     'monasca-api': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-api/'
-                     'monasca-api-2.2.0.tar.gz')},
+                     'monasca-api-2.5.0.tar.gz')},
     'monasca-log-api': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-log-api/'
-                     'monasca-log-api-2.3.0.tar.gz')},
+                     'monasca-log-api-2.6.0.tar.gz')},
     'monasca-notification': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-notification/'
-                     'monasca-notification-1.10.1.tar.gz')},
+                     'monasca-notification-1.13.0.tar.gz')},
     'monasca-persister': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-persister/'
-                     'monasca-persister-1.7.0.tar.gz')},
+                     'monasca-persister-1.10.0.tar.gz')},
     'monasca-statsd': {
         'type': 'url',
         'location': ('$tarballs_base/monasca-statsd/'
-                     'monasca-statsd-1.7.0.tar.gz')},
+                     'monasca-statsd-1.9.0.tar.gz')},
     'murano-base': {
         'type': 'url',
         'location': ('$tarballs_base/murano/'
-                     'murano-4.0.0.tar.gz')},
+                     'murano-5.0.0.tar.gz')},
     'neutron-base': {
         'type': 'url',
         'location': ('$tarballs_base/neutron/'
-                     'neutron-11.0.6.tar.gz')},
+                     'neutron-12.0.3.tar.gz')},
     'neutron-base-plugin-neutron-fwaas': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-fwaas/'
-                     'neutron-fwaas-11.0.2.tar.gz')},
+                     'neutron-fwaas-12.0.0.tar.gz')},
+    'neutron-base-plugin-networking-baremetal': {
+        'type': 'url',
+        'location': ('$tarballs_base/networking-baremetal/'
+                     'networking-baremetal-1.0.0.tar.gz')},
     'neutron-base-plugin-networking-generic-switch': {
         'type': 'url',
         'location': ('$tarballs_base/networking-generic-switch/'
-                     'networking-generic-switch-0.4.0.tar.gz')},
+                     'networking-generic-switch-1.0.0.tar.gz')},
     'neutron-base-plugin-networking-sfc': {
         'type': 'url',
         'location': ('$tarballs_base/networking-sfc/'
-                     'networking-sfc-5.0.0.tar.gz')},
+                     'networking-sfc-6.0.0.tar.gz')},
     'neutron-base-plugin-vmware-nsx': {
         'type': 'url',
         'location': ('$tarballs_base/vmware-nsx/'
-                     'vmware-nsx-11.0.0.tar.gz')},
+                     'vmware-nsx-12.0.1.tar.gz')},
+    'neutron-base-plugin-vpnaas-agent': {
+        'type': 'url',
+        'location': ('$tarballs_base/neutron-vpnaas/'
+                     'neutron-vpnaas-12.0.0.tar.gz')},
     'neutron-bgp-dragent': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-dynamic-routing/'
-                     'neutron-dynamic-routing-11.0.1.tar.gz')},
+                     'neutron-dynamic-routing-12.0.1.tar.gz')},
     'neutron-lbaas-agent': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-lbaas/'
-                     'neutron-lbaas-11.0.3.tar.gz')},
+                     'neutron-lbaas-12.0.0.tar.gz')},
     'neutron-server-opendaylight-plugin-networking-odl': {
         'type': 'url',
         'location': ('$tarballs_base/networking-odl/'
-                     'networking-odl-11.0.0.tar.gz')},
+                     'networking-odl-12.0.0.tar.gz')},
     'neutron-server-opendaylight-plugin-networking-bgpvpn': {
         'type': 'url',
         'location': ('$tarballs_base/networking-bgpvpn/'
-                     'networking-bgpvpn-7.0.0.tar.gz')},
+                     'networking-bgpvpn-8.0.0.tar.gz')},
     'neutron-server-opendaylight-plugin-networking-l2gw': {
         'type': 'url',
         'location': ('$tarballs_base/networking-l2gw/'
-                     'networking-l2gw-11.0.0.tar.gz')},
+                     'networking-l2gw-12.0.1.tar.gz')},
     'neutron-server-opendaylight-plugin-networking-sfc': {
         'type': 'url',
         'location': ('$tarballs_base/networking-sfc/'
-                     'networking-sfc-5.0.0.tar.gz')},
+                     'networking-sfc-6.0.0.tar.gz')},
     'neutron-server-plugin-neutron-dynamic-routing': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-dynamic-routing/'
-                     'neutron-dynamic-routing-11.0.1.tar.gz')},
+                     'neutron-dynamic-routing-12.0.1.tar.gz')},
     'neutron-server-plugin-neutron-lbaas': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-lbaas/'
-                     'neutron-lbaas-11.0.3.tar.gz')},
+                     'neutron-lbaas-12.0.0.tar.gz')},
     'neutron-server-plugin-vmware-nsxlib': {
         'type': 'url',
         'location': ('$tarballs_base/vmware-nsxlib/'
-                     'vmware-nsxlib-11.1.2.tar.gz')},
-    'neutron-server-plugin-vpnaas-agent': {
-        'type': 'url',
-        'location': ('$tarballs_base/neutron-vpnaas/'
-                     'neutron-vpnaas-11.0.0.tar.gz')},
+                     'vmware-nsxlib-12.0.1.tar.gz')},
     'neutron-vpnaas-agent': {
         'type': 'url',
         'location': ('$tarballs_base/neutron-vpnaas/'
-                     'neutron-vpnaas-11.0.0.tar.gz')},
+                     'neutron-vpnaas-12.0.0.tar.gz')},
     'neutron-server-ovn-plugin-networking-ovn': {
         'type': 'url',
         'location': ('$tarballs_base/networking-ovn/'
-                     'networking-ovn-3.0.1.tar.gz')},
+                     'networking-ovn-4.0.2.tar.gz')},
+    'neutron-metadata-agent-ovn-plugin-networking-ovn': {
+        'type': 'url',
+        'location': ('$tarballs_base/networking-ovn/'
+                     'networking-ovn-4.0.2.tar.gz')},
     'nova-base': {
         'type': 'url',
         'location': ('$tarballs_base/nova/'
-                     'nova-16.1.7.tar.gz')},
+                     'nova-17.0.5.tar.gz')},
     'nova-base-plugin-blazar': {
         'type': 'url',
         'location': ('$tarballs_base/blazar-nova/'
-                     'blazar-nova-0.3.0.tar.gz')},
+                     'blazar-nova-1.0.1.tar.gz')},
+    'nova-base-plugin-mksproxy': {
+        'type': 'url',
+        'location': ('$tarballs_base/nova-mksproxy/'
+                     'nova-mksproxy-master.tar.gz')},
     'novajoin-base': {
         'type': 'url',
         'location': ('$tarballs_base/novajoin/'
-                     'novajoin-1.0.17.tar.gz')},
+                     'novajoin-1.0.18.tar.gz')},
     'octavia-base': {
         'type': 'url',
         'location': ('$tarballs_base/octavia/'
-                     'octavia-1.0.4.tar.gz')},
+                     'octavia-2.0.1.tar.gz')},
     'opendaylight': {
         'type': 'url',
         'location': ('https://nexus.opendaylight.org/content/'
                      'repositories/opendaylight.release/org/opendaylight/'
-                     'integration/distribution-karaf/0.6.1-Carbon/'
-                     'distribution-karaf-0.6.1-Carbon.tar.gz')},
+                     'integration/distribution-karaf/0.6.2-Carbon/'
+                     'distribution-karaf-0.6.2-Carbon.tar.gz')},
     'panko-base': {
         'type': 'url',
         'location': ('$tarballs_base/panko/'
-                     'panko-3.1.0.tar.gz')},
+                     'panko-4.0.1.tar.gz')},
+    'tempest-plugin-tempest-conf': {
+        'type': 'url',
+        'location': ('$tarballs_base/python-tempestconf/'
+                     'python-tempestconf-1.1.4.tar.gz')},
     'rally': {
         'type': 'url',
         'location': ('$tarballs_base/rally/'
@@ -599,39 +639,47 @@ SOURCES = {
     'sahara-base': {
         'type': 'url',
         'location': ('$tarballs_base/sahara/'
-                     'sahara-7.0.3.tar.gz')},
+                     'sahara-8.0.1.tar.gz')},
     'searchlight-base': {
         'type': 'url',
         'location': ('$tarballs_base/searchlight/'
-                     'searchlight-3.0.0.tar.gz')},
+                     'searchlight-4.0.0.tar.gz')},
     'senlin-base': {
         'type': 'url',
         'location': ('$tarballs_base/senlin/'
-                     'senlin-4.0.0.tar.gz')},
+                     'senlin-5.0.1.tar.gz')},
     'solum-base': {
         'type': 'url',
         'location': ('$tarballs_base/solum/'
-                     'solum-5.4.0.tar.gz')},
+                     'solum-5.5.1.tar.gz')},
     'swift-base': {
         'type': 'url',
         'location': ('$tarballs_base/swift/'
-                     'swift-2.15.2.tar.gz')},
+                     'swift-2.17.0.tar.gz')},
     'tacker-base': {
         'type': 'url',
         'location': ('$tarballs_base/tacker/'
-                     'tacker-0.8.1.tar.gz')},
+                     'tacker-0.9.0.tar.gz')},
+    'tacker-base-plugin-networking-sfc': {
+        'type': 'url',
+        'location': ('$tarballs_base/networking-sfc/'
+                     'networking-sfc-6.0.0.tar.gz')},
     'tempest': {
         'type': 'url',
         'location': ('$tarballs_base/tempest/'
-                     'tempest-17.0.0.tar.gz')},
+                     'tempest-master.tar.gz')},
+    'tripleo-ui': {
+        'type': 'url',
+        'location': ('$tarballs_base/tripleo-ui/'
+                     'tripleo-ui-8.3.2.tar.gz')},
     'trove-base': {
         'type': 'url',
         'location': ('$tarballs_base/trove/'
-                     'trove-8.0.0.tar.gz')},
+                     'trove-9.0.0.tar.gz')},
     'vitrage-base': {
         'type': 'url',
         'location': ('$tarballs_base/vitrage/'
-                     'vitrage-1.8.2.tar.gz')},
+                     'vitrage-2.3.0.tar.gz')},
     'vmtp': {
         'type': 'url',
         'location': ('$tarballs_base/vmtp/'
@@ -639,15 +687,15 @@ SOURCES = {
     'watcher-base': {
         'type': 'url',
         'location': ('$tarballs_base/watcher/'
-                     'python-watcher-1.4.1.tar.gz')},
+                     'python-watcher-1.8.0.tar.gz')},
     'zaqar': {
         'type': 'url',
         'location': ('$tarballs_base/zaqar/'
-                     'zaqar-5.0.0.tar.gz')},
+                     'zaqar-6.0.1.tar.gz')},
     'zun-base': {
         'type': 'url',
         'location': ('$tarballs_base/zun/'
-                     'zun-0.2.1.tar.gz')}
+                     'zun-1.0.0.tar.gz')}
 }
 
 
