@@ -37,6 +37,7 @@ from oslo_config import cfg
 from requests import exceptions as requests_exc
 import six
 
+
 # NOTE(SamYaple): Update the search path to prefer PROJECT_ROOT as the source
 #                 of packages to import if we are using local tools instead of
 #                 pip installed kolla tools
@@ -47,34 +48,14 @@ if PROJECT_ROOT not in sys.path:
 
 from kolla.common import config as common_config
 from kolla.common import task
+from kolla.common import utils
 from kolla import exception
 from kolla.template import filters as jinja_filters
 from kolla.template import methods as jinja_methods
 from kolla import version
 
 
-def make_a_logger(conf=None, image_name=None):
-    if image_name:
-        log = logging.getLogger(".".join([__name__, image_name]))
-    else:
-        log = logging.getLogger(__name__)
-    if not log.handlers:
-        if conf is None or not conf.logs_dir or not image_name:
-            handler = logging.StreamHandler(sys.stderr)
-            log.propagate = False
-        else:
-            filename = os.path.join(conf.logs_dir, "%s.log" % image_name)
-            handler = logging.FileHandler(filename, delay=True)
-        handler.setFormatter(logging.Formatter(logging.BASIC_FORMAT))
-        log.addHandler(handler)
-    if conf is not None and conf.debug:
-        log.setLevel(logging.DEBUG)
-    else:
-        log.setLevel(logging.INFO)
-    return log
-
-
-LOG = make_a_logger()
+LOG = utils.make_a_logger()
 
 # Image status constants.
 #
@@ -95,6 +76,132 @@ STATUS_ERRORS = (STATUS_CONNECTION_ERROR, STATUS_PUSH_ERROR,
                  STATUS_ERROR, STATUS_PARENT_ERROR)
 
 
+SKIPPED_IMAGES = {
+    'centos+binary': [
+        "almanach-base",
+        "bifrost-base",
+        "blazar-base",
+        "dragonflow-base",
+        "freezer-base",
+        "karbor-base",
+        "kuryr-base",
+        "monasca-base",
+        "neutron-bgp-dragent",
+        "nova-mksproxy",
+        "ovsdpdk",
+        "searchlight-base",
+        "senlin-base",
+        "solum-base",
+        # NOTE(jeffrey4l): There is no openstack-tripleo-ui package in
+        # centos queens repo
+        "tripleo-ui",
+        "vmtp",
+        "zun-base",
+    ],
+    'centos+source': [
+        "ovsdpdk",
+        # TODO(mandre) remove after fixing
+        # https://bugs.launchpad.net/kolla/+bug/1774123
+        "sensu-base",
+        # TODO(jeffrey4l): remove tripleo-ui when following bug is fixed
+        # https://bugs.launchpad.net/tripleo/+bug/1744215
+        "tripleo-ui"
+    ],
+    'ubuntu+binary': [
+        "almanach-base",
+        "bifrost-base",
+        "blazar-base",
+        "cloudkitty-base",
+        "congress-base",
+        "dragonflow-base",
+        "ec2-api",
+        "freezer-base",
+        "heat-all",
+        "ironic-neutron-agent",
+        "karbor-base",
+        "kuryr-base",
+        "mistral-event-engine",
+        "monasca-base",
+        "nova-mksproxy",
+        "novajoin-base",
+        "octavia-base",
+        "searchlight-base",
+        "senlin-base",
+        "solum-base",
+        "tacker-base",
+        "tripleo-ui",
+        "vitrage-base",
+        "vmtp",
+        "zaqar",
+        "zun-base",
+    ],
+    'ubuntu+source': [
+        "tripleo-ui"
+    ],
+    'debian+binary': [
+        "almanach-base",
+        "bifrost-base",
+        "blazar-base",
+        "cloudkitty-base",
+        "congress-base",
+        "dragonflow-base",
+        "ec2-api",
+        "freezer-base",
+        "heat-all",
+        "ironic-neutron-agent",
+        "karbor-base",
+        "kuryr-base",
+        "mistral-event-engine",
+        "monasca-base",
+        "nova-mksproxy",
+        "novajoin-base",
+        "octavia-base",
+        "searchlight-base",
+        "senlin-base",
+        "sensu-base",
+        "solum-base",
+        "tacker-base",
+        "tripleo-ui",
+        "vitrage-base",
+        "vmtp",
+        "zaqar",
+        "zun-base"
+    ],
+    'debian+source': [
+        "sensu-base",
+        "tripleo-ui"
+    ],
+    'oraclelinux+binary': [
+        "almanach-base",
+        "bifrost-base",
+        "blazar-base",
+        "dragonflow-base",
+        "freezer-base",
+        "karbor-base",
+        "kuryr-base",
+        "monasca-base",
+        "nova-mksproxy",
+        "neutron-bgp-dragent",
+        "ovsdpdk",
+        "searchlight-base",
+        "senlin-base",
+        "solum-base",
+        # NOTE(jeffrey4l): There is no openstack-tripleo-ui package in
+        # centos queens repo
+        "tripleo-ui",
+        "vmtp",
+        "zun-base"
+    ],
+    'oraclelinux+source': [
+        "bifrost-base",
+        "ovsdpdk",
+        # TODO(jeffrey4l): remove tripleo-ui when following bug is fixed
+        # https://bugs.launchpad.net/tripleo/+bug/1744215
+        "tripleo-ui"
+    ]
+}
+
+
 class ArchivingError(Exception):
     pass
 
@@ -149,7 +256,7 @@ class Image(object):
         self.source = source
         self.parent_name = parent_name
         if logger is None:
-            logger = make_a_logger(image_name=name)
+            logger = utils.make_a_logger(image_name=name)
         self.logger = logger
         self.children = []
         self.plugins = []
@@ -480,6 +587,9 @@ class BuildTask(DockerTask):
                         if line:
                             self.logger.error('%s', line)
                     return
+
+            if image.status != STATUS_ERROR and self.conf.squash:
+                self.squash()
         except docker.errors.DockerException:
             image.status = STATUS_ERROR
             self.logger.exception('Unknown docker error when building')
@@ -490,6 +600,19 @@ class BuildTask(DockerTask):
             image.status = STATUS_BUILT
             self.logger.info('Built')
 
+    def squash(self):
+        image_tag = self.image.canonical_name
+        image_id = self.dc.inspect_image(image_tag)['Id']
+
+        parent_history = self.dc.history(self.image.parent_name)
+        parent_last_layer = parent_history[0]['Id']
+        self.logger.info('Parent lastest layer is: %s' % parent_last_layer)
+
+        utils.squash(image_id, image_tag, from_layer=parent_last_layer,
+                     cleanup=self.conf.squash_cleanup,
+                     tmp_dir=self.conf.squash_tmp_dir)
+        self.logger.info('Image is squashed successfully')
+
 
 class WorkerThread(threading.Thread):
     """Thread that executes tasks until the queue provides a tombstone."""
@@ -605,7 +728,7 @@ class KollaWorker(object):
 
         for path in possible_paths:
             image_path = os.path.join(path, 'docker')
-            # NOTE(SamYaple): We explicty check for the base folder to ensure
+            # NOTE(SamYaple): We explicitly check for the base folder to ensure
             #                 this is the correct path
             # TODO(SamYaple): Improve this to make this safer
             if os.path.exists(os.path.join(image_path, 'base')):
@@ -773,7 +896,7 @@ class KollaWorker(object):
                 env.filters.update(self._get_filters())
                 env.globals.update(self._get_methods())
                 template = env.get_template(template_name)
-            content = template.render(values)
+            content = template.render(values, env=os.environ)
             content_path = os.path.join(path, 'Dockerfile')
             with open(content_path, 'w') as f:
                 LOG.debug("Rendered %s into:", tpl_path)
@@ -854,6 +977,12 @@ class KollaWorker(object):
             for image in self.images:
                 image.status = STATUS_MATCHED
 
+        skipped_images = SKIPPED_IMAGES.get('%s+%s' % (self.base,
+                                                       self.install_type))
+        for image in self.images:
+            if image.name in skipped_images:
+                image.status = STATUS_UNMATCHED
+
     def summary(self):
         """Walk the dictionary of images statuses and print results."""
         # For debug we print the logs again if the image error'd. This is to
@@ -976,7 +1105,7 @@ class KollaWorker(object):
             del match
             image = Image(image_name, canonical_name, path,
                           parent_name=parent_name,
-                          logger=make_a_logger(self.conf, image_name),
+                          logger=utils.make_a_logger(self.conf, image_name),
                           docker_client=self.dc)
 
             if self.install_type == 'source':
@@ -1094,7 +1223,7 @@ class KollaWorker(object):
         queue = six.moves.queue.Queue()
 
         for image in self.images:
-            if image.status == STATUS_UNMATCHED:
+            if image.status in (STATUS_UNMATCHED, STATUS_SKIPPED):
                 # Don't bother queuing up build tasks for things that
                 # were not matched in the first place... (not worth the
                 # effort to run them, if they won't be used anyway).
@@ -1109,8 +1238,8 @@ class KollaWorker(object):
 def run_build():
     """Build container images.
 
-    :return: A 3-tuple containing bad, good, and unmatched container image
-    status dicts, or None if no images were built.
+    :return: A 4-tuple containing bad, good, unmatched and skipped container
+    image status dicts, or None if no images were built.
     """
     conf = cfg.ConfigOpts()
     common_config.parse(conf, sys.argv[1:], prog='kolla-build')
@@ -1118,6 +1247,13 @@ def run_build():
     if conf.debug:
         LOG.setLevel(logging.DEBUG)
 
+    if conf.squash:
+        squash_version = utils.get_docker_squash_version()
+        LOG.info('Image squash is enabled and "docker-squash" version is %s',
+                 squash_version)
+    else:
+        LOG.info('Image squash is disabled')
+
     kolla = KollaWorker(conf)
     kolla.setup_working_dir()
     kolla.find_dockerfiles()
